# LocalRequirement

LocalRequirement is a Python tool that updates the versions of packages in a `requirements.txt` file to match the versions installed locally on your machine.

## Installation

You can install LocalRequirement using pip: